@@ -33,7 +33,7 @@ class BCELossMetrics():
     def auc(y_hat, labels):
         with torch.no_grad():
             auc_fn = AUROC()
-            auc = auc_fn(y_hat, labels)
+            auc = auc_fn(y_hat, labels).float()
         return auc
 
     def __call__(
@@ -62,7 +62,7 @@ class CELossMetrics():
     def auc(y_hat, labels):
         with torch.no_grad():
             auc_fn = AUROC()
-            auc = auc_fn(y_hat, labels)
+            auc = auc_fn(y_hat, labels).float()
         return auc
     
     def __call__(
@@ -168,7 +168,7 @@ class CEDiceLossMetrics():
     def auc(y_hat, labels):
         with torch.no_grad():
             auc_fn = AUROC()
-            auc = auc_fn(y_hat, labels)
+            auc = auc_fn(y_hat, labels).float()
         return auc
 
     def __call__(
